@@ -245,8 +245,10 @@ OC.L10N.register(
     "Untitled event" : "Eventu ensin títulu",
     "Airplane" : "Avión",
     "Train" : "Tren",
+    "Help" : "Ayuda",
     "contains" : "contién",
     "matches" : "concasa",
+    "Actions" : "Aiciones",
     "Priority" : "Prioridá",
     "delete" : "desaniciar",
     "Edit" : "Editar",
@@ -308,9 +310,6 @@ OC.L10N.register(
     "Could not load the message" : "Nun se pudo cargar el mensaxe",
     "Error loading message" : "Hebo un error al cargar el mensaxe",
     "Redirect" : "Redirixir",
-    "The link leads to %s" : "L'enllaz lleva a %s",
-    "Flag" : "Bandera",
-    "Operator" : "Operador",
-    "Filter name" : "Nome de la peñera"
+    "The link leads to %s" : "L'enllaz lleva a %s"
 },
 "nplurals=2; plural=(n != 1);");
