@@ -2,6 +2,7 @@ OC.L10N.register(
     "mail",
     {
     "Work" : "Праца",
+    "Personal" : "Асабістыя",
     "Mail" : "Пошта",
     "You are reaching your mailbox quota limit for {account_email}" : "Вы дасягаеце ліміту квоты вашай паштовай скрынкі для {account_email} ",
     "Save" : "Захаваць",
@@ -59,13 +60,22 @@ OC.L10N.register(
     "Discard & close draft" : "Адхіліць і закрыць чарнавік",
     "Enable formatting" : "Уключыць фарматаванне",
     "Disable formatting" : "Выключыць фарматаванне",
+    "Tomorrow morning" : "Заўтра ранкам",
+    "Tomorrow afternoon" : "Заўтра ў другой палове дня",
     "Enter a date" : "Увядзіце дату",
     "Choose" : "Выбраць",
     "Confirm" : "Пацвердзіць",
     "Rich text" : "Фарматаваны тэкст",
     "No messages in this folder" : "У гэтай папцы няма паведамленняў",
     "No messages" : "Няма паведамленняў",
+    "Later today – {timeLocale}" : "Пазней сёння – {timeLocale}",
+    "Set reminder for later today" : "Задаць напамін на пазней сёння",
     "Tomorrow – {timeLocale}" : "Заўтра – {timeLocale}",
+    "Set reminder for tomorrow" : "Задаць напамін на заўтра",
+    "This weekend – {timeLocale}" : "У гэты ўік-энд – {timeLocale}",
+    "Set reminder for this weekend" : "Задаць напамін на гэты ўік-энд",
+    "Next week – {timeLocale}" : "На наступным тыдні – {timeLocale}",
+    "Set reminder for next week" : "Задаць напамін на наступны тыдзень",
     "Encrypted message" : "Зашыфраванае паведамленне",
     "Favorite" : "Абранае",
     "Unread" : "Непрачытанае",
@@ -74,6 +84,7 @@ OC.L10N.register(
     "Delete message" : "Выдаліць паведамленне",
     "More actions" : "Больш дзеянняў",
     "Back" : "Назад",
+    "_Forward {number} as attachment_::_Forward {number} as attachment_" : ["Пераслаць {number} як далучэнне","Пераслаць {number} як далучэнне","Пераслаць {number} як далучэнне","Пераслаць {number} як далучэнне"],
     "Mark as unread" : "Пазначыць як непрачытанае",
     "Mark as read" : "Пазначыць як прачытанае",
     "Attendees" : "Удзельнікі",
@@ -95,6 +106,7 @@ OC.L10N.register(
     "Forward" : "Пераслаць",
     "Move message" : "Перамясціць паведамленне",
     "Translate" : "Перакласці",
+    "Forward message as attachment" : "Пераслаць паведамленне як далучэнне",
     "Unnamed" : "Без назвы",
     "Download Zip" : "Спампаваць Zip",
     "Move" : "Перамясціць",
@@ -152,7 +164,11 @@ OC.L10N.register(
     "Copy translated text" : "Скапіяваць перакладзены тэкст",
     "Untitled event" : "Падзея без назвы",
     "Train" : "Цягнік",
+    "Move into folder" : "Перамясціць у папку",
+    "Stop" : "Спыніць",
     "Delete filter" : "Выдаліць фільтр",
+    "Help" : "Даведка",
+    "Actions" : "Дзеянні",
     "Tag" : "Тэг",
     "delete" : "выдаліць",
     "Edit" : "Рэдагаваць",
@@ -189,6 +205,7 @@ OC.L10N.register(
     "Priority inbox" : "Прыярытэтныя",
     "Inbox" : "Уваходныя",
     "Sent" : "Адпраўленыя",
+    "Error while sharing file" : "Памылка пры абагульванні файла",
     "_%n new message \nfrom {from}_::_%n new messages \nfrom {from}_" : ["%n новае паведамленне \nад {from}","%n новыя паведамленні \nад {from}","%n новых паведамленняў \nад {from}","%n новых паведамленняў \nад {from}"],
     "Discard changes" : "Адхіліць змены",
     "Discard unsaved changes" : "Адхіліць незахаваныя змены",
@@ -202,7 +219,6 @@ OC.L10N.register(
     "Could not load your message" : "Не ўдалося загрузіць ваша паведамленне",
     "Could not load the message" : "Не ўдалося загрузіць паведамленне",
     "Error loading message" : "Памылка пры загрузцы паведамлення",
-    "Flag" : "Сцяг",
-    "Operator" : "Аператар"
+    "Forwarding to %s" : "Перасыланне да %s"
 },
 "nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);");
