@@ -287,6 +287,7 @@ OC.L10N.register(
     "Sync in background" : "Synkroniser i baggrunden",
     "Outbox" : "Udbakke",
     "New message" : "Ny besked",
+    "Edit message" : "Rediger besked",
     "Draft" : "Kladde",
     "Reply" : "Besvar",
     "You are trying to send to many recipients in To and/or Cc. Consider using Bcc to hide recipient addresses." : "Du prøver at sende til mange modtagere i Til og/eller Cc. Overvej at bruge Bcc til at skjule modtageradresser.",
@@ -343,8 +344,10 @@ OC.L10N.register(
     "Train" : "Tog",
     "Recipient" : "Modtager",
     "New filter" : "Nyt filter",
+    "Help" : "Hjælp",
     "contains" : "indeholder",
     "matches" : "er lig med",
+    "Actions" : "Handlinger",
     "Priority" : "Prioritet",
     "delete" : "Slet",
     "Edit" : "Redigér",
@@ -406,8 +409,6 @@ OC.L10N.register(
     "Click here if you are not automatically redirected within the next few seconds." : "Klik her hvis du ikke automatisk bliver videre sendt i løbet af et par sekunder.",
     "Redirect" : "Omdiriger",
     "The link leads to %s" : "Linket fører til %s",
-    "Continue to %s" : "Videre til %s",
-    "Looking for a way to encrypt your emails?" : "Leder du efter en måde at kryptere dine e-mails på?",
-    "Operator" : "Operatør"
+    "Continue to %s" : "Videre til %s"
 },
 "nplurals=2; plural=(n != 1);");
