@@ -104,7 +104,9 @@ OC.L10N.register(
     "Add tag" : "Agregar etiqueta",
     "Not found" : "No encontrado",
     "Recipient" : "Destinatario",
+    "Help" : "Ayuda",
     "matches" : "coincide",
+    "Actions" : "Acciones",
     "Priority" : "Prioridad",
     "delete" : "borrar",
     "Edit" : "Editar",
