@@ -402,8 +402,16 @@ OC.L10N.register(
     "Unsubscribe" : "Rimuovi sottoscrizione",
     "Reply to sender only" : "Rispondi solo al mittente",
     "Go to latest message" : "Vai all'ultimo messaggio",
+    "The message could not be translated" : "Questo messaggio non può essere tradotto",
+    "Translation copied to clipboard" : "Traduzione copiata negli appunti",
+    "Translation could not be copied" : "La traduzione non può essere copiata",
+    "Translate message" : "Traduci messaggio",
+    "Source language to translate from" : "Lingua di partenza da cui tradurre",
     "Translate from" : "Traduci da",
+    "Target language to translate into" : "Lingua di destinazione in cui tradurre",
     "Translate to" : "Traduci in",
+    "Translating" : "Traduco",
+    "Copy translated text" : "Copia testo tradotto",
     "Could not remove trusted sender {sender}" : "Impossibile rimuovere il mittente fidato {sender}",
     "No senders are trusted at the moment." : "Nessun mittente è fidato al momento.",
     "Untitled event" : "Evento senza titolo",
@@ -416,9 +424,12 @@ OC.L10N.register(
     "{trainNr} from {depStation} to {arrStation}" : "{trainNr} da {depStation} a {arrStation}",
     "Train from {depStation} to {arrStation}" : "Treno da {depStation} a {arrStation}",
     "Train" : "Treno",
+    "Stop" : "Ferma",
     "Recipient" : "Destinatario",
+    "Help" : "Assistenza",
     "contains" : "contiene",
     "matches" : "corrisponde",
+    "Actions" : "Azioni",
     "Priority" : "Priorità",
     "Tag" : "Etichetta",
     "delete" : "elimina",
@@ -557,8 +568,6 @@ OC.L10N.register(
     "Click here if you are not automatically redirected within the next few seconds." : "Fai clic qui se non viene rediretto automaticamente entro pochi secondi.",
     "Redirect" : "Redirigi",
     "The link leads to %s" : "Il collegamento conduce a %s",
-    "Continue to %s" : "Continua su %s",
-    "Flag" : "Bandiera",
-    "Operator" : "Operatore"
+    "Continue to %s" : "Continua su %s"
 },
 "nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
