@@ -8,12 +8,14 @@ OC.L10N.register(
     "Name" : "Nom",
     "Password" : "Awal uffir",
     "None" : "Ula d yiwen",
+    "Go back" : "Tuɣalin",
     "Email address" : "Tansa imayl",
     "Cancel" : "Sefsex",
     "Accounts" : "Imiḍanen",
     "General" : "Amatu",
     "List" : "Tabdart",
     "About" : "Γef",
+    "Keyboard shortcuts" : "Inegzumen n unasiw",
     "Delete" : "Kkes",
     "Search" : "Nadi",
     "Send" : "Tuzna",
@@ -21,6 +23,7 @@ OC.L10N.register(
     "Choose" : "Fren",
     "Confirm" : "Serggeg",
     "Favorite" : "Menyif",
+    "More actions" : "Ugar n tigawin",
     "Back" : "Retour",
     "Mark as unread" : "Creḍ ur yettwaɣra ara",
     "Mark as read" : "Creḍ yettwaɣra",
@@ -34,7 +37,9 @@ OC.L10N.register(
     "Translate" : "Suqel",
     "Move" : "Senkez",
     "Remove account" : "Kkes amiḍan",
+    "Folder name" : "Isem n ukaram",
     "Loading …" : "Asali ...",
+    "Delete folder" : "Kkes akaram",
     "Rename" : "Beddel isem",
     "Reply" : "Err",
     "Retry" : "Ɛreḍ tikkelt-nniḍen",
@@ -44,16 +49,22 @@ OC.L10N.register(
     "Close" : "Mdel",
     "Date" : "Azemz",
     "Tags" : "Tibzimin",
+    "Last 7 days" : "7 n wussan yezrin",
+    "Not found" : "Ulac-it",
     "Translate from" : "Suqel seg",
     "Translate to" : "Suqel ar",
+    "Help" : "Tallalt",
+    "Actions" : "Tigawin",
     "Edit" : "Ẓreg",
     "User" : "Aseqdac",
     "Guest" : "Inebgi",
     "Group" : "Agraw",
+    "Account connected" : "Amiḍan d uqqin",
     "All" : "Akk",
     "Favorites" : "Imenyafen",
     "Inbox" : "Tanaka",
     "Nextcloud Mail" : "Imayl n Nextcloud",
-    "Message sent" : "Izen yettwazen"
+    "Message sent" : "Izen yettwazen",
+    "Continue to %s" : "Kemmel ar %s"
 },
 "nplurals=2; plural=(n != 1);");
