@@ -196,7 +196,9 @@ OC.L10N.register(
     "Set reminder for later today" : "Постави потсетник за денес покасно",
     "Tomorrow – {timeLocale}" : "Утре – {timeLocale}",
     "Set reminder for tomorrow" : "Постави потсетник за утре",
+    "This weekend – {timeLocale}" : "Овој викенд – {timeLocale}",
     "Set reminder for this weekend" : "Постави потсетник за овој викенд",
+    "Next week – {timeLocale}" : "Следна недела – {timeLocale}",
     "Set reminder for next week" : "Постави потсетник за наредната недела",
     "Could not delete message" : "Неможе да се избрише пораката",
     "This message is unread" : "Оваа порака не е прочитана",
@@ -403,7 +405,9 @@ OC.L10N.register(
     "{trainNr} from {depStation} to {arrStation}" : "{trainNr} од {depStation} до {arrStation}",
     "Train from {depStation} to {arrStation}" : "Воз од  {depStation} до {arrStation}",
     "Train" : "Воз",
+    "Help" : "Помош",
     "matches" : "се совпаѓа",
+    "Actions" : "Акции",
     "Priority" : "Приоритет",
     "delete" : "избриши",
     "Edit" : "Уреди",
@@ -482,7 +486,6 @@ OC.L10N.register(
     "Redirect" : "Пренасочи",
     "The link leads to %s" : "Линкот води кон %s",
     "If you do not want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "Доколку несакате да ја посетите страната, можете да се вратите кон <a href=\"%s\">Е-пошта</a>.",
-    "Continue to %s" : "Продолжи до %s",
-    "Flag" : "Знаме"
+    "Continue to %s" : "Продолжи до %s"
 },
 "nplurals=2; plural=(n % 10 == 1 && n % 100 != 11) ? 0 : 1;");
