@@ -74,7 +74,9 @@ OC.L10N.register(
     "Tags" : "Tag-үүд",
     "Custom" : "Дурын",
     "Recipient" : "Хүлээн авагч",
+    "Help" : "Туслах",
     "matches" : "тохируулах",
+    "Actions" : "Үйл ажиллагаа",
     "delete" : "устгах",
     "Edit" : "Өөрчлөх",
     "Reset" : "тохируулах",
