@@ -198,8 +198,10 @@ OC.L10N.register(
     "Reservation {id}" : "Reserva {id}",
     "Train" : "Comboio",
     "Recipient" : "Destinatário",
+    "Help" : "Ajuda",
     "contains" : "contém",
     "matches" : "corresponde",
+    "Actions" : "Ações",
     "Priority" : "Prioridade",
     "Tag" : "Etiqueta",
     "delete" : "eliminar",
@@ -244,8 +246,6 @@ OC.L10N.register(
     "Click here if you are not automatically redirected within the next few seconds." : "Clique aqui se não for automaticamente redirecionado dentro de segundos.",
     "Redirect" : "Redirecionar",
     "The link leads to %s" : "A ligação aponta para %s",
-    "Continue to %s" : "Continuar para %s",
-    "Operator" : "Operador",
-    "Filter name" : "Filtrar nome"
+    "Continue to %s" : "Continuar para %s"
 },
 "nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
