@@ -45,6 +45,8 @@ OC.L10N.register(
     "Close" : "වසන්න",
     "Body" : "අන්තර්ගතය",
     "Date" : "දිනය",
+    "Help" : "උපකාර",
+    "Actions" : "ක්‍රියාමාර්ග",
     "Edit" : "සංස්කරණය",
     "User" : "පරිශීලක",
     "Host" : " ධාරකය",
