@@ -543,6 +543,7 @@ OC.L10N.register(
     "{trainNr} from {depStation} to {arrStation}" : "{trainNr} {depStation} دىن {arrStation} غىچە",
     "Train from {depStation} to {arrStation}" : "{depStation} دىن {arrStation} غا بارىدىغان پويىز",
     "Train" : "پويىز",
+    "Stop" : "توختاڭ",
     "Delete action" : "ھەرىكەتنى ئۆچۈرۈڭ",
     "Delete filter" : "سۈزگۈچنى ئۆچۈرۈڭ",
     "Delete mail filter {filterName}?" : "خەت سۈزگۈچنى ئۆچۈرۈڭ {filterName}?",
@@ -555,10 +556,12 @@ OC.L10N.register(
     "Take control of your email chaos. Filters help you to prioritize what matters and eliminate clutter." : "ئېلېكترونلۇق خەت قالايمىقانچىلىقىڭىزنى كونترول قىلىڭ. سۈزگۈچلەر مۇھىم ئىشلارنى مۇھىم ئورۇنغا قويۇپ ، قالايمىقانچىلىقنى تۈگىتىشىڭىزگە ياردەم بېرىدۇ.",
     "Filter is active" : "سۈزگۈچ ئاكتىپ",
     "Filter is not active" : "سۈزگۈچ ئاكتىپ ئەمەس",
+    "Help" : "ياردەم",
     "contains" : "بار",
     "A substring match. The field matches if the provided value is contained within it. For example, \"report\" would match \"port\"." : "Subring match. ئەگەر تەمىنلەنگەن قىممەت ئۇنىڭ ئىچىدە بولسا ، مەيدان ماس كېلىدۇ. مەسىلەن ، «دوكلات» «پورت» بىلەن ماس كېلىدۇ.",
     "matches" : "match",
     "A pattern match using wildcards. The \"*\" symbol represents any number of characters (including none), while \"?\" represents exactly one character. For example, \"*report*\" would match \"Business report 2024\"." : "ياۋايى كارتا ئىشلىتىپ ئەندىزە ماس كېلىدۇ. \"*\" بەلگىسى ھەرپ-بەلگىلەرنى كۆرسىتىدۇ (ھېچقايسىسىنى ئۆز ئىچىگە ئالمايدۇ) ، \"?\" دەل بىر ھەرپكە ۋەكىللىك قىلىدۇ. مەسىلەن ، «* دوكلات *» «سودا دوكلاتى 2024» بىلەن ماس كېلىدۇ.",
+    "Actions" : "مەشغۇلاتلار",
     "Priority" : "ھەممىدىن مۇھىم",
     "Enable filter" : "سۈزگۈچنى قوزغىتىڭ",
     "delete" : "ئۆچۈر",
@@ -710,22 +713,6 @@ OC.L10N.register(
     "Redirect" : "قايتا نىشانلاش",
     "The link leads to %s" : "ئۇلىنىش% s نى كەلتۈرۈپ چىقىرىدۇ",
     "If you do not want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "ئەگەر ئۇ بەتنى زىيارەت قىلىشنى خالىمىسىڭىز ، <a href = \"% s\"> خەت </a> گە قايتسىڭىز بولىدۇ.",
-    "Continue to %s" : "داۋاملىق% s",
-    "Mailvelope is enabled for the current domain!" : "خەت ساندۇقى نۆۋەتتىكى دائىرە ئۈچۈن قوزغىتىلدى!",
-    "Looking for a way to encrypt your emails?" : "ئېلېكترونلۇق خەتلىرىڭىزنى مەخپىيلەشتۈرۈشنىڭ يولىنى ئىزدەۋاتامسىز؟",
-    "Enable Mailvelope for the current domain" : "نۆۋەتتىكى دائىرە ئۈچۈن Mailvelope نى قوزغىتىڭ",
-    "Flag" : "بايراق",
-    "The stop action ends all processing" : "توختىتىش ھەرىكىتى بارلىق بىر تەرەپ قىلىشنى ئاخىرلاشتۇرىدۇ",
-    "Operator" : "Operator",
-    "Delete test" : "سىناقنى ئۆچۈرۈڭ",
-    "Update mail filter" : "خەت سۈزگۈچنى يېڭىلاڭ",
-    "Filter name" : "سۈزگۈچ ئىسمى",
-    "Tests are applied to incoming emails on your mail server, targeting fields such as subject (the email's subject line), from (the sender), and to (the recipient). You can use the following operators to define conditions for these fields:" : "ئىمتىھان ئېلېكترونلۇق خەت مۇلازىمېتىرىڭىزدىكى كەلگەن ئېلېكترونلۇق خەتلەرگە ، تېما (ئېلېكترونلۇق خەتنىڭ تېما لىنىيىسى) ، (ئەۋەتكۈچى) ۋە (تاپشۇرۇۋالغۇچى) غا ئوخشاش ساھەگە ئىشلىتىلىدۇ. تۆۋەندىكى مەشغۇلاتلارنى ئىشلىتىپ بۇ ساھەنىڭ شەرتلىرىنى بەلگىلىيەلەيسىز:",
-    "An exact match. The field must be identical to the provided value." : "ئېنىق ماس. بۇ ساھە چوقۇم تەمىنلەنگەن قىممەت بىلەن ئوخشاش بولۇشى كېرەك.",
-    "Actions are triggered when the specified tests are true. The following actions are available:" : "كۆرسىتىلگەن سىناقلار توغرا بولغاندا ھەرىكەت قوزغىلىدۇ. تۆۋەندىكى ھەرىكەتلەر بار:",
-    "Moves the message into a specified folder." : "ئۇچۇرنى بەلگىلەنگەن قىسقۇچقا يۆتكەيدۇ.",
-    "Adds a flag to the message." : "ئۇچۇرغا بايراق قوشىدۇ.",
-    "Halts the execution of the filter script. No further filters with will be processed after this action." : "سۈزگۈچ قوليازمىسىنىڭ ئىجرا قىلىنىشىنى توختىتىدۇ. بۇ ھەرىكەتتىن كېيىن باشقا سۈزگۈچلەر بىر تەرەپ قىلىنمايدۇ.",
-    "Save filter" : "سۈزگۈچنى ساقلاڭ"
+    "Continue to %s" : "داۋاملىق% s"
 },
 "nplurals=2; plural=(n != 1);");
